@@ -41,7 +41,6 @@ public:
     QFuture<VideoResult> requestVideo(const QString &videoId) override;
     QFuture<SearchListResult> requestSearchResults(const SearchParameters &parameters, Paginator *paginator = nullptr) override;
     QFuture<VideoListResult> requestFeed(Paginator *paginator = nullptr) override;
-    QFuture<VideoListResult> requestTop() override;
     QFuture<VideoListResult> requestTrending(TrendingTopic = Main, Paginator *paginator = nullptr) override;
     QFuture<VideoListResult> requestChannel(const QString &query, Paginator *paginator = nullptr) override;
     QFuture<SubscriptionsResult> requestSubscriptions() override;
@@ -59,6 +58,7 @@ public:
     QFuture<PlaylistsResult> requestChannelPlaylists(const QString &channelId) override;
     QFuture<Result> addVideoToPlaylist(const QString &plid, const QString &videoId) override;
     QFuture<Result> removeVideoFromPlaylist(const QString &plid, const QString &indexId) override;
+    QString getVideoUrl(const QString &videoId) override;
 
 private:
     enum VideoListType { Search, Trending, Top, Feed, Channel };
