@@ -22,7 +22,6 @@ bool SubscriptionController::canToggleSubscription() const
 {
     // subscriptions need to be loaded and no other task needs to run
     return PlasmaTube::instance().selectedSource()->loggedIn() && PlasmaTube::instance().selectedSource()->subscriptions().has_value() && !m_watcher;
-    return false;
 }
 
 void SubscriptionController::toggleSubscription()
@@ -37,7 +36,7 @@ void SubscriptionController::toggleSubscription()
                                  : PlasmaTube::instance().sourceManager()->selectedSource()->api()->subscribeToChannel(channelId());
 
     m_watcher = new QFutureWatcher<QInvidious::Result>(this);
-    connect(m_watcher, &QFutureWatcherBase::finished, this, [=] {
+    connect(m_watcher, &QFutureWatcherBase::finished, this, [this] {
         auto result = m_watcher->result();
         if (std::holds_alternative<QInvidious::Success>(result)) {
             auto &subs = PlasmaTube::instance().selectedSource()->subscriptions();
